==> pmml-model-1.3.8-sources.jar: org/dmg/pmml/VerificationFields.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.model.Property;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}VerificationField" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "verificationFields"
})
@XmlRootElement(name = "VerificationFields", namespace = "http://www.dmg.org/PMML-4_3")
public class VerificationFields
    extends org.dmg.pmml.PMMLObject
    implements Iterable<VerificationField> , HasExtensions<VerificationFields>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    @XmlElement(name = "VerificationField", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    private List<VerificationField> verificationFields;
    private final static long serialVersionUID = 67305478L;

    public VerificationFields() {
    }

    public VerificationFields(
        @Property("verificationFields")
        List<VerificationField> verificationFields) {
        this.verificationFields = verificationFields;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the verificationFields property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the verificationFields property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVerificationFields().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VerificationField }
     * 
     * 
     */
    public List<VerificationField> getVerificationFields() {
        if (verificationFields == null) {
            verificationFields = new ArrayList<VerificationField>();
        }
        return this.verificationFields;
    }

    public Iterator<VerificationField> iterator() {
        return getVerificationFields().iterator();
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public VerificationFields addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasVerificationFields() {
        return ((this.verificationFields!= null)&&(this.verificationFields.size()> 0));
    }

    public VerificationFields addVerificationFields(VerificationField... verificationFields) {
        getVerificationFields().addAll(Arrays.asList(verificationFields));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasVerificationFields()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getVerificationFields());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.4.2-sources.jar: org/dmg/pmml/VerificationFields.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "verificationFields"
})
@XmlRootElement(name = "VerificationFields", namespace = "http://www.dmg.org/PMML-4_3")
public class VerificationFields
    extends org.dmg.pmml.PMMLObject
    implements Iterable<VerificationField> , HasExtensions<VerificationFields>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    @XmlElement(name = "VerificationField", namespace = "http://www.dmg.org/PMML-4_3", required = true)
    private List<VerificationField> verificationFields;
    private final static long serialVersionUID = 67305482L;

    public VerificationFields() {
    }

    public VerificationFields(
        @Property("verificationFields")
        List<VerificationField> verificationFields) {
        this.verificationFields = verificationFields;
    }

    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public List<VerificationField> getVerificationFields() {
        if (verificationFields == null) {
            verificationFields = new ArrayList<VerificationField>();
        }
        return this.verificationFields;
    }

    public Iterator<VerificationField> iterator() {
        return getVerificationFields().iterator();
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public VerificationFields addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasVerificationFields() {
        return ((this.verificationFields!= null)&&(this.verificationFields.size()> 0));
    }

    public VerificationFields addVerificationFields(VerificationField... verificationFields) {
        getVerificationFields().addAll(Arrays.asList(verificationFields));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasVerificationFields()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getVerificationFields());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
